summaryrefslogtreecommitdiffstats
path: root/widget/nsBaseDragService.cpp
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-12 05:35:29 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-06-12 05:35:29 +0000
commit59203c63bb777a3bacec32fb8830fba33540e809 (patch)
tree58298e711c0ff0575818c30485b44a2f21bf28a0 /widget/nsBaseDragService.cpp
parentAdding upstream version 126.0.1. (diff)
downloadfirefox-59203c63bb777a3bacec32fb8830fba33540e809.tar.xz
firefox-59203c63bb777a3bacec32fb8830fba33540e809.zip
Adding upstream version 127.0.upstream/127.0
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'widget/nsBaseDragService.cpp')
-rw-r--r--widget/nsBaseDragService.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/widget/nsBaseDragService.cpp b/widget/nsBaseDragService.cpp
index 22ed844595..c79d5bbb6d 100644
--- a/widget/nsBaseDragService.cpp
+++ b/widget/nsBaseDragService.cpp
@@ -368,7 +368,7 @@ nsBaseDragService::InvokeDragSession(
nsCOMPtr<nsITransferable> trans =
do_CreateInstance("@mozilla.org/widget/transferable;1");
trans->Init(nullptr);
- trans->SetRequestingPrincipal(mSourceNode->NodePrincipal());
+ trans->SetDataPrincipal(mSourceNode->NodePrincipal());
trans->SetContentPolicyType(mContentPolicyType);
trans->SetCookieJarSettings(aCookieJarSettings);
mutableArray->AppendElement(trans);
@@ -378,8 +378,8 @@ nsBaseDragService::InvokeDragSession(
nsCOMPtr<nsITransferable> trans =
do_QueryElementAt(aTransferableArray, i);
if (trans) {
- // Set the requestingPrincipal on the transferable.
- trans->SetRequestingPrincipal(mSourceNode->NodePrincipal());
+ // Set the dataPrincipal on the transferable.
+ trans->SetDataPrincipal(mSourceNode->NodePrincipal());
trans->SetContentPolicyType(mContentPolicyType);
trans->SetCookieJarSettings(aCookieJarSettings);
}